@@ -58,7 +58,6 @@
 #include "misc.h"
 #include "pasteboard.h"
 #include "settings.h"
-#include "xfstab.h"
 #include "toolbar.h"
 
 /* if themes.mime.xml does not exist...*/
@@ -84,8 +83,8 @@ static const gchar *composite_type_id(const gchar *path,int type,int subtype,con
 	g_free(composite_type);
 	composite_type=g_strdup(id);
 	if (path){
-	    if (IS_DIR(type) && is_mounted(path)==1) greenball=TRUE;
-	    else if (is_in_fstab(path) && !IS_XF_FSTAB(type)) redball=TRUE;
+	    if (IS_DIR(type) && FSTAB_is_mounted(path)==1) greenball=TRUE;
+	    else if (FSTAB_is_in_fstab(path) && !IS_XF_FSTAB(type)) redball=TRUE;
 	}
 	if (IS_NOWRITE(type)||IS_XF_LNK(type)||HAS_HIDDEN(type)||greenball||redball||IS_NETREADONLY(subtype)||IS_XF_NETSHARE(subtype)){
 	    p=composite_type;
@@ -248,9 +247,11 @@ GdkPixbuf *create_preview (char *file, int size)
     double scaleW, scaleH, scale;
     GError *error = NULL;
     const gchar *thumbnail_path=get_thumbnail_path(file,size);
+
+    TRACE("preview %s",file);
     
     if (thumbnail_path && g_file_test(thumbnail_path,G_FILE_TEST_EXISTS)){
-	DBG("retrieving thumbnail for %s (%s)",file,thumbnail_path);
+	TRACE("retrieving thumbnail for %s (%s)",file,thumbnail_path);
 	tgt = gdk_pixbuf_new_from_file(thumbnail_path, NULL);
 	if (tgt) return tgt;
     }
@@ -258,10 +259,14 @@ GdkPixbuf *create_preview (char *file, int size)
     switch (size)
     {
 	default:
+	    max_w = w = 96, h = 48;
+	    break;
+	case SMALL:
 	    max_w = w = 48, h = 24;
 	    break;
 	case MEDIUM:
-	    max_w = w = 68, h = 34;
+	    //max_w = w = 68, h = 34;
+	    max_w = w = 100, h = 50;
 	    break;
 	case BIG:
 	    max_w = w = 100, h = 50;
@@ -271,19 +276,33 @@ GdkPixbuf *create_preview (char *file, int size)
 	    break;
     }
 
-    src = gdk_pixbuf_new_from_file(file, &error);
-    if(!src)
-    {
-	/*printf("DBG: pixbuf error, file=%s\n",file); */
-	return NULL;
-    }
+#if GTK_CHECK_VERSION (2,4,0)
+    src = gdk_pixbuf_new_from_file_at_size (file,w,h,&error);
     if(error){
+	g_warning(error->message);
 	g_error_free(error);
 	error=NULL;
+	return NULL;
     }
+#else /* gtk < 2.4 */
+    src = gdk_pixbuf_new_from_file(file, &error);
+    if(error || !src){
+	if (error) {
+	    g_warning("file=%s (%s)",file,error->message);
+	    g_error_free(error);
+	}
+	error=NULL;
+	return NULL;
+    }
+#endif
 
     ph = gdk_pixbuf_get_height(src);
     pw = gdk_pixbuf_get_width(src);
+    if (ph <= 0 || pw <= 0 || scale <=0) {
+	g_object_unref(src);
+	return NULL;
+    }
+
     area=ph*pw;
     if ((ph > h || pw > w) && pw > 0 && ph > 0){
       scaleH = (double)h / ph;
@@ -868,8 +887,8 @@ const gchar *resolve_icon_id (tree_entry_t * en)
   GTK_STATE_PRELIGHT,
   GTK_STATE_SELECTED,
   GTK_STATE_INSENSITIVE*/
-
-static GdkPixbuf *resolve_icon (tree_entry_t * en, tree_entry_t * p_en)
+/* use parameter for iconview size */
+static GdkPixbuf *resolve_icon (tree_entry_t * en, tree_entry_t * p_en, int s)
 {
     int gtksize, size;
     char *loc = NULL;
@@ -884,7 +903,11 @@ static GdkPixbuf *resolve_icon (tree_entry_t * en, tree_entry_t * p_en)
 
     if(!style) style = gtk_style_new();
 
-    switch (tree_details->icon_size){
+    if (s<0) {
+	gtksize = GTK_ICON_SIZE_DIALOG;
+	size = REAL_BIG;
+    }
+    else switch (tree_details->icon_size){
       case 3:
 	gtksize = GTK_ICON_SIZE_DIALOG;
 	size = REAL_BIG;
@@ -935,7 +958,8 @@ static GdkPixbuf *resolve_icon (tree_entry_t * en, tree_entry_t * p_en)
     {
  	GdkPixbuf *tgt;
         process_pending_gtk(); 
-	tgt = create_preview(en->path, size);
+	if (s>=0) tgt = create_preview(en->path, size);
+	else tgt = create_preview(en->path, s);
 	if(tgt) return tgt;
     }
     
@@ -1025,11 +1049,21 @@ void set_icon (GtkTreeModel *treemodel, GtkTreeIter * iterator)
 	return;
     /*if (en->path) printf("DBG: icon setting for %s\n",en->path); */
     set_font(treemodel,iterator); 
-    Icon = resolve_icon(en, p_en);
+    Icon = resolve_icon(en, p_en,0);
     update_iconcolumn_for_row(treemodel, iterator,Icon);	
     if (Icon) g_object_unref (G_OBJECT (Icon));    
 }
 
+G_MODULE_EXPORT
+GdkPixbuf *get_icon (tree_entry_t *en,tree_entry_t *p_en)
+{
+    GdkPixbuf *Icon;
+    if (!en) return NULL;  
+    TRACE("shows images=%d",SHOWS_IMAGES(p_en->type)); 
+    Icon = resolve_icon(en, p_en,-1);
+    return Icon;
+}
+
 G_MODULE_EXPORT
 void update_icon (GtkTreeModel *treemodel, GtkTreeIter * iterator)
 {
@@ -1057,7 +1091,7 @@ void update_icon (GtkTreeModel *treemodel, GtkTreeIter * iterator)
 	{
 	    memcpy(en->st, &st, sizeof(struct stat));
 	    en->count = count_files(en->path);
-	    Icon = resolve_icon(en, p_en);
+	    Icon = resolve_icon(en, p_en,0);
 	    D(printf(".");fflush(NULL);)
 	    update_iconcolumn_for_row(treemodel, iterator,Icon);	
 	    update_text_cell_for_row(SIZE_COLUMN,treemodel, iterator,sizetag((off_t)-1, en->count)); 
@@ -1070,7 +1104,7 @@ void update_icon (GtkTreeModel *treemodel, GtkTreeIter * iterator)
     if(IS_CUT(en->type) || in_pasteboard(en)==2)
     {
 	/*printf("dbg update icon %s\n",en->path); */
-	Icon = resolve_icon(en, p_en);
+	Icon = resolve_icon(en, p_en,0);
         update_iconcolumn_for_row(treemodel, iterator,Icon);	
 	if (Icon) g_object_unref (G_OBJECT (Icon));    
 	if(in_pasteboard(en)==2){
