@@ -845,12 +845,19 @@ void sb_xfce_setting_show(GtkWidget *w){
     return;
  
 }
+/* This is screwy on remote connections: 
 G_MODULE_EXPORT
 void on_tb_off(GtkWidget *w){
     gchar *argv[]={"xfce4-session-logout",NULL};
     runv(argv);
     return;
  
+}*/
+G_MODULE_EXPORT
+void on_tb_off(GtkWidget *w){
+    exit(1);
+    return;
+ 
 }
 
 G_MODULE_EXPORT
@@ -917,9 +924,10 @@ void toolbar_buttons(void){
     /*gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));*/
     normal_buttons(toolbar,normal_button_info1);
     smart_buttons(toolbar,paste_button_info,"paste_button");
-    normal_buttons(toolbar,normal_button_info1b);
+    gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
     smart_buttons(toolbar,new_button_info,"new_button");
     smart_buttons(toolbar,single_selection_button_info,"single_selection_button");
+    normal_buttons(toolbar,normal_button_info1b);
     /* separator is added in normal button info */
     normal_buttons(toolbar,normal_button_info2);
 
