@@ -5,5 +5,5 @@ void create_root_element(GtkTreeView * treeview,  GtkTreeIter *iterator,
 		int i,const gchar *home);
 
 
-GtkTreeView *init_xffm(int argc, char *argv[]);
+GtkTreeView *init_xffm_treeviews(int argc, char *argv[]);
 #endif
